@@ -1,11 +1,11 @@
 package Net::RDAP::Help;
 use base qw(Net::RDAP::Object);
 use strict;
+use warnings;
 
 =head1 NAME
 
-L<Net::RDAP::Help> - an RDAP object representing a help
-response.
+L<Net::RDAP::Help> - a module representing an RDAP help response.
 
 =head1 DESCRIPTION
 
