@@ -21,6 +21,7 @@ use constant {
 };
 use base qw(Exporter);
 use strict;
+use warnings;
 
 #
 # export these symbols
@@ -41,7 +42,8 @@ our ($UA, $REGISTRY);
 
 =head1 NAME
 
-L<Net::RDAP::Values> - interface to the RDAP values registry.
+L<Net::RDAP::Values> - a module which provides interface to the RDAP values
+registry.
 
 =head1 DESCRIPTION
 
